==> jc-1.4.0.tar.gz: gnu/xml/dom/DomDocumentFragment.h <==
// public class gnu.xml.dom.DomDocumentFragment

// class file dependencies
// @dep_class 20e8df863ec6895d gnu_xml_dom_DomDocumentFragment
// @dep_class 5b5336c9987ffef5 gnu_xml_dom_DomNode
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header gnu_xml_dom_DomNode

#include "gnu/xml/dom/DomNode.h"

#ifndef _JC_gnu_xml_dom_DomDocumentFragment_H_
#define _JC_gnu_xml_dom_DomDocumentFragment_H_

// Forward structure declarations
struct _jc_gnu_xml_dom_DomDocument$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_xml_dom_DomDocumentFragment$sub_refs	_jc_gnu_xml_dom_DomDocumentFragment$sub_refs;
typedef struct _jc_gnu_xml_dom_DomDocumentFragment$sub_nonrefs	_jc_gnu_xml_dom_DomDocumentFragment$sub_nonrefs;
typedef struct _jc_gnu_xml_dom_DomDocumentFragment$refs	_jc_gnu_xml_dom_DomDocumentFragment$refs;
typedef struct _jc_gnu_xml_dom_DomDocumentFragment$nonrefs	_jc_gnu_xml_dom_DomDocumentFragment$nonrefs;
typedef struct _jc_gnu_xml_dom_DomDocumentFragment$object	_jc_gnu_xml_dom_DomDocumentFragment$object;

typedef const struct _jc_gnu_xml_dom_DomDocumentFragment$vmethods	_jc_gnu_xml_dom_DomDocumentFragment$vmethods;
typedef const struct _jc_gnu_xml_dom_DomDocumentFragment$vtable	_jc_gnu_xml_dom_DomDocumentFragment$vtable;
typedef const struct _jc_gnu_xml_dom_DomDocumentFragment$vtype	_jc_gnu_xml_dom_DomDocumentFragment$vtype;

// Constructors
extern void _jc_gnu_xml_dom_DomDocumentFragment$method$_init$134c9d3f286300ed(_jc_env *, struct _jc_gnu_xml_dom_DomDocumentFragment$object *, struct _jc_gnu_xml_dom_DomDocument$object *);

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_gnu_xml_dom_DomDocumentFragment$method$getNodeName$f5b11134ac79aed1(_jc_env *, struct _jc_gnu_xml_dom_DomDocumentFragment$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_dom_DomDocumentFragment$method_info$getNodeName$f5b11134ac79aed1;

// Virtual methods structure
struct _jc_gnu_xml_dom_DomDocumentFragment$vmethods {
	struct _jc_java_lang_String$object	*(*getNodeName$f5b11134ac79aed1)(_jc_env *, struct _jc_gnu_xml_dom_DomDocumentFragment$object *);
};

// Vtable
struct _jc_gnu_xml_dom_DomDocumentFragment$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_dom_DomNode$vmethods	gnu_xml_dom_DomNode;
	_jc_gnu_xml_dom_DomDocumentFragment$vmethods	gnu_xml_dom_DomDocumentFragment;
};

// Vtype
struct _jc_gnu_xml_dom_DomDocumentFragment$vtype {
	_jc_type			type;
	_jc_gnu_xml_dom_DomDocumentFragment$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_dom_DomDocumentFragment$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_xml_dom_DomDocumentFragment$refs {
    _jc_gnu_xml_dom_DomDocumentFragment$sub_refs	gnu_xml_dom_DomDocumentFragment;
    _jc_gnu_xml_dom_DomNode$sub_refs	gnu_xml_dom_DomNode;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_dom_DomDocumentFragment$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_dom_DomDocumentFragment$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_dom_DomNode$sub_nonrefs	gnu_xml_dom_DomNode;
    _jc_gnu_xml_dom_DomDocumentFragment$sub_nonrefs	gnu_xml_dom_DomDocumentFragment;
};

// Object instance structure
struct _jc_gnu_xml_dom_DomDocumentFragment$object {
	_jc_gnu_xml_dom_DomDocumentFragment$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_dom_DomDocumentFragment$vtype	*vtype;
	_jc_gnu_xml_dom_DomDocumentFragment$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_dom_DomDocumentFragment$vtype _jc_gnu_xml_dom_DomDocumentFragment$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_dom_DomDocumentFragment, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_dom_DomDocumentFragment$class_object;

#endif	/* _JC_gnu_xml_dom_DomDocumentFragment_H_ */

==> jc-1.4.5.tar.gz: gnu/xml/dom/DomDocumentFragment.h <==
// public class gnu.xml.dom.DomDocumentFragment

// class file dependencies
// @dep_class 20e8df863ec6895d gnu_xml_dom_DomDocumentFragment
// @dep_class 4ec94c6db3eac49b gnu_xml_dom_DomNode
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header gnu_xml_dom_DomNode

#include "gnu/xml/dom/DomNode.h"

#ifndef _JC_gnu_xml_dom_DomDocumentFragment_H_
#define _JC_gnu_xml_dom_DomDocumentFragment_H_

// Forward structure declarations
struct _jc_gnu_xml_dom_DomDocument$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_xml_dom_DomDocumentFragment$sub_refs	_jc_gnu_xml_dom_DomDocumentFragment$sub_refs;
typedef struct _jc_gnu_xml_dom_DomDocumentFragment$sub_nonrefs	_jc_gnu_xml_dom_DomDocumentFragment$sub_nonrefs;
typedef struct _jc_gnu_xml_dom_DomDocumentFragment$refs	_jc_gnu_xml_dom_DomDocumentFragment$refs;
typedef struct _jc_gnu_xml_dom_DomDocumentFragment$nonrefs	_jc_gnu_xml_dom_DomDocumentFragment$nonrefs;
typedef struct _jc_gnu_xml_dom_DomDocumentFragment$object	_jc_gnu_xml_dom_DomDocumentFragment$object;

typedef const struct _jc_gnu_xml_dom_DomDocumentFragment$vmethods	_jc_gnu_xml_dom_DomDocumentFragment$vmethods;
typedef const struct _jc_gnu_xml_dom_DomDocumentFragment$vtable	_jc_gnu_xml_dom_DomDocumentFragment$vtable;
typedef const struct _jc_gnu_xml_dom_DomDocumentFragment$vtype	_jc_gnu_xml_dom_DomDocumentFragment$vtype;

// Constructors
extern void _jc_gnu_xml_dom_DomDocumentFragment$method$_init$134c9d3f286300ed(_jc_env *, struct _jc_gnu_xml_dom_DomDocumentFragment$object *, struct _jc_gnu_xml_dom_DomDocument$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_gnu_xml_dom_DomDocumentFragment$method$getNodeName$f5b11134ac79aed1(_jc_env *, struct _jc_gnu_xml_dom_DomDocumentFragment$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_dom_DomDocumentFragment$method_info$getNodeName$f5b11134ac79aed1;

// Virtual methods structure
struct _jc_gnu_xml_dom_DomDocumentFragment$vmethods {
	struct _jc_java_lang_String$object	*(*getNodeName$f5b11134ac79aed1)(_jc_env *, struct _jc_gnu_xml_dom_DomDocumentFragment$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_xml_dom_DomDocumentFragment$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_dom_DomNode$vmethods	gnu_xml_dom_DomNode;
	_jc_gnu_xml_dom_DomDocumentFragment$vmethods	gnu_xml_dom_DomDocumentFragment;
};

// Vtype
struct _jc_gnu_xml_dom_DomDocumentFragment$vtype {
	_jc_type			type;
	_jc_gnu_xml_dom_DomDocumentFragment$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_dom_DomDocumentFragment$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_xml_dom_DomDocumentFragment$refs {
    _jc_gnu_xml_dom_DomDocumentFragment$sub_refs	gnu_xml_dom_DomDocumentFragment;
    _jc_gnu_xml_dom_DomNode$sub_refs	gnu_xml_dom_DomNode;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_dom_DomDocumentFragment$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_dom_DomDocumentFragment$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_dom_DomNode$sub_nonrefs	gnu_xml_dom_DomNode;
    _jc_gnu_xml_dom_DomDocumentFragment$sub_nonrefs	gnu_xml_dom_DomDocumentFragment;
};

// Object instance structure
struct _jc_gnu_xml_dom_DomDocumentFragment$object {
	_jc_gnu_xml_dom_DomDocumentFragment$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_dom_DomDocumentFragment$vtype	*vtype;
	_jc_gnu_xml_dom_DomDocumentFragment$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_dom_DomDocumentFragment$vtype _jc_gnu_xml_dom_DomDocumentFragment$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_dom_DomDocumentFragment, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_dom_DomDocumentFragment$class_object;

#endif	/* _JC_gnu_xml_dom_DomDocumentFragment_H_ */
